@@ -18,6 +18,6 @@ def fetch_and_save_file(url, fn):
         ) as f:          
             f.raise_for_status()
             for r in f.iter_content(chunk_size=1024*1024):
-                outf.write(fn)                
+                outf.write(r)                
         
     
\ No newline at end of file
